import { IDisposable } from '@phosphor/disposable';
import { Widget } from '@phosphor/widgets';
import { RenderMime } from '@jupyterlab/rendermime';
import { WidgetManager } from './manager';
/**
 * A renderer for widgets.
 */
export declare class WidgetRenderer implements RenderMime.IRenderer, IDisposable {
    constructor(widgetManager: WidgetManager);
    /**
     * Whether the renderer can render given the render options.
     *
     * @param options - The options that would be used to render the data.
     */
    canRender(options: RenderMime.IRenderOptions): boolean;
    /**
     * Whether the renderer will sanitize the data given the render options.
     */
    wouldSanitize(options: RenderMime.IRenderOptions): boolean;
    /**
     * Render the transformed mime data.
     *
     * @param options - The options used to render the data.
     */
    render(options: RenderMime.IRenderOptions): Widget;
    /**
     * Get whether the manager is disposed.
     *
     * #### Notes
     * This is a read-only property.
     */
    readonly isDisposed: boolean;
    /**
     * Dispose the resources held by the manager.
     */
    dispose(): void;
    mimeTypes: string[];
    private _manager;
}
